from django.conf import settings as django_settings
from django.core.exceptions import ImproperlyConfigured
from django_auto_static_libs.libraries import jquery
import os

DJANGO_AUTO_STATIC_LIBS = dict(libraries={
	'jquery': jquery
}, destination_folder='django-auto-static-libs')

if hasattr(django_settings, "DJANGO_AUTO_STATIC_LIBS"):
	if 'libraries' in getattr(django_settings, "DJANGO_AUTO_STATIC_LIBS"):
		DJANGO_AUTO_STATIC_LIBS['libraries'] = getattr(django_settings, "DJANGO_AUTO_STATIC_LIBS")['libraries']
	DJANGO_AUTO_STATIC_LIBS = {**DJANGO_AUTO_STATIC_LIBS, **getattr(django_settings, "DJANGO_AUTO_STATIC_LIBS")}

# check whether the folder is a proper path
if not os.path.isabs(DJANGO_AUTO_STATIC_LIBS['destination_folder']):
	if not hasattr(django_settings, "STATIC_ROOT"):
		raise ImproperlyConfigured("Django-auto-static-libs needs STATIC_ROOT in settings.py")
	STATIC_ROOT = getattr(django_settings, "STATIC_ROOT")
	DESTINATION_ROOT=os.path.join(STATIC_ROOT,DJANGO_AUTO_STATIC_LIBS['destination_folder'])
else:
	DESTINATION_ROOT=DJANGO_AUTO_STATIC_LIBS['destination_folder']



# -*- coding: utf-8 -*-
from django.apps import AppConfig
import sys
from django.core import management


class AutoStaticLibsConfig(AppConfig):
	name = 'django_auto_static_libs'
	verbose_name = 'Django auto static lib updater'

	def ready(self):

		if 'manage.py' in sys.argv and "migrate" in sys.argv and len(sys.argv) == 2:
			management.call_command('static-libs-download', verbosity=0)


from django_auto_static_libs.providers.GithubProvider import GithubProvider
from django_auto_static_libs.providers.BaseProvider import SingleUrlProvider,SingleUrlByExtractProvider
default = {
	'suffix_ignore': [],
	'files_include': '(.*)',
	'destination': "auto",
}

jquery = {
	'provider': GithubProvider("jquery/jquery"),
	'suffix_ignore': [".json"],
	'files_include': r"jquery-[\d\.]+/dist/(.*\.(js|map))",
	'destination': "auto",
}
jquery_ui = {
	'provider': SingleUrlByExtractProvider("https://jqueryui.com/",regex=r'href="(?P<url>.*)".*class="button".*>(?=.*\bstable\b).+</a>'),
	'suffix_ignore': [""],
	'files_include': r"jquery-ui-[\d\.]+/(.*)",
	'destination': "auto",
}
fomantic_ui = {
	'provider': GithubProvider("fomantic/Fomantic-UI"),
	'suffix_ignore': [".json"],
	'files_include': r"Fomantic-UI-[\d\.]+/dist/(.*)",
	'destination': "auto",
}
semantic_ui = {
	'provider': GithubProvider("Semantic-Org/Semantic-UI"),
	'suffix_ignore': [".json"],
	'files_include': r"Semantic-UI-[\d\.]+/dist/(.*)",
	'destination': "auto",
}
masonry = {
	'provider': GithubProvider("desandro/masonry"),
	'suffix_ignore': [],
	'files_include': r"masonry-[\d\.]+/dist/(.*)",
	'destination': "auto",
}
pygal_js = {
	'provider': SingleUrlProvider(
		["https://raw.githubusercontent.com/Kozea/pygal.js/gh-pages/javascripts/pygal-tooltips.js",
		 "https://raw.githubusercontent.com/Kozea/pygal.js/gh-pages/javascripts/svg.jquery.js"]),
	'suffix_ignore': [],
	'files_include': '(.*)',
	'destination': "auto",
}
bootstrap={
    'provider':SingleUrlByExtractProvider("https://github.com/twbs/bootstrap",words=["download","latest","release"]),
	'suffix_ignore': [],
	'files_include': 'bootstrap-.*/dist/(.*)',
	'destination': "auto",
}
fontawesome = {
	'provider': GithubProvider("FortAwesome/Font-Awesome",file="releases/download/{response_json[tag_name]}/fontawesome-free-{response_json[tag_name]}-web.zip"),
	'suffix_ignore': [],
	'files_include': r"fontawesome-[^/]*/(.*)",
	'destination': "auto",
}


from os.path import join, dirname
from distutils.core import setup

try:
	with open("README.md", "r", encoding="utf-8") as fh:
		long_description = fh.read()

except IOError:
	long_description = None

version = __import__('django_auto_static_libs').get_version()

setup(
	name='django-auto-static-libs',
	version=version,
	url="https://github.com/rokdd/django-auto-static-libs",
	download_url='https://github.com/rokdd/django-auto-static-libs/archive/refs/tags/v%s.tar.gz' % version,
	description='jQuery and other librarys ready to download self hosted and embed into templates',
	long_description="Provide basic libraries and resources like jQuery or semantic-ui in django applications. Make it easier for keeping them updated and self-hosted. ",
	author='rokdd',
	author_email='r0kdd@yahoo.com',
	license='BSD',
	keywords='django jquery fontawesome pygal javascript static'.split(),
	platforms='any',
	long_description_content_type='text/markdown',
	classifiers=[
		'Environment :: Web Environment',
		'Framework :: Django',
		'Natural Language :: English',
		'Operating System :: OS Independent',
		'Programming Language :: Python',
	],
	packages=['django_auto_static_libs'],

	install_requires=[
		'requests',
	]
)